@@ -767,7 +767,7 @@ def get_cr(
             with setup_logging(own_logs_dir):
                 logger.debug("running get_cr()", delete=delete, copy_to_machine_cache=copy_to_machine_cache)
                 challenge_parameters_ = EvaluationParameters.from_yaml(res["challenge_parameters"])
-                logger.info(challenge_parameters_=challenge_parameters_)
+                # logger.info(challenge_parameters_=challenge_parameters_)
                 rnd = random.randint(1, 1000000)
 
                 project = f"{evaluator_name}-job{job_id}-{rnd}"
@@ -1087,31 +1087,33 @@ def run_one(
 
             client = check_docker_environment()
             service2id = get_services_id(wd, project, services)
-            logger.debug(service2id=service2id)
-            for service_name, container_id in service2id.items():
-                container: Container = client.containers.get(container_id)
-                container.reload()
-                #
-                # cpu.cfs_quota_us: the total available run-time within a period (in microseconds)
-                # cpu.cfs_period_us: the length of a period (in microseconds)
-                # cpu.stat: exports throttling statistics [explained further below]
+            # logger.debug(service2id=service2id)
+            enable_quotas = False
+            if enable_quotas:
+                for service_name, container_id in service2id.items():
+                    container: Container = client.containers.get(container_id)
+                    container.reload()
+                    #
+                    # cpu.cfs_quota_us: the total available run-time within a period (in microseconds)
+                    # cpu.cfs_period_us: the length of a period (in microseconds)
+                    # cpu.stat: exports throttling statistics [explained further below]
 
-                container.update(cpu_shares=250)
+                    container.update(cpu_shares=250)
 
-                if is_solution_container(service_name):
-                    M = "8g"
-                    container.update(memswap_limit=-1, mem_reservation=M, mem_limit=M)
-                    if quota_cpu is not None:
-                        # every second
-                        cpu_period = 1000 * 1000
-                        # get 300% cpu
-                        cpu_quota = int(quota_cpu * 1000 * 1000)
+                    if is_solution_container(service_name):
+                        M = "8g"
+                        container.update(memswap_limit=-1, mem_reservation=M, mem_limit=M)
+                        if quota_cpu is not None:
+                            # every second
+                            cpu_period = 1000 * 1000
+                            # get 300% cpu
+                            cpu_quota = int(quota_cpu * 1000 * 1000)
 
-                        container.update(cpu_period=cpu_period, cpu_quota=cpu_quota)
-                        msg = "Applying CPU quota"
-                        logger.info(
-                            msg, service_name=service_name, cpu_period=cpu_period, cpu_quota=cpu_quota,
-                        )
+                            container.update(cpu_period=cpu_period, cpu_quota=cpu_quota)
+                            msg = "Applying CPU quota"
+                            logger.debug(
+                                msg, service_name=service_name, cpu_period=cpu_period, cpu_quota=cpu_quota,
+                            )
 
             logger.debug(f"Starting services", services=services)
             cmd = ["up", "-d"]
